#ifndef NT2_INCLUDE_FUNCTIONS_IS_NOT_LESS_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_NOT_LESS_EQUAL_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_not_less_equal.hpp>

#endif
